import re
import pandas as pd
from datetime import datetime


def first_match_or_empty(pattern: str, text: str) -> str:
    """Get the first match for the provided pattern or "" if empty.
    This is a wrapper to facilitate usage of the re.search in lambda expressions

    Args:
        pattern: Pattern to search for
        text: Text that will be searched

    Returns: First pattern match or ""

    """
    match = re.search(pattern, text)
    if match:
        return match.group(1)
    else:
        return ""


def to_datetime_safe(datetime_str: str):
    try:
        return pd.to_datetime(datetime_str, format="mixed", errors="coerce")
    except (ValueError, AttributeError):
        return datetime.now()
